@@ -19,12 +19,11 @@
 
 """Misc. CompletionModels."""
 
-from collections import defaultdict
 from PyQt5.QtCore import Qt, QTimer, pyqtSlot
 
-from qutebrowser.browser import webview
+from qutebrowser.browser import browsertab
 from qutebrowser.config import config, configdata
-from qutebrowser.utils import objreg, log, qtutils, utils
+from qutebrowser.utils import objreg, log, qtutils
 from qutebrowser.commands import cmdutils
 from qutebrowser.completion.models import base
 
@@ -53,14 +52,8 @@ class CommandCompletionModel(base.BaseCompletionModel):
         cat = self.new_category("Commands")
 
         # map each command to its bound keys and show these in the misc column
-        keyconf = objreg.get('key-config')
-        cmd_to_keys = defaultdict(list)
-        for key, cmd in keyconf.get_bindings_for('normal').items():
-            # put special bindings last
-            if utils.is_special_key(key):
-                cmd_to_keys[cmd].append(key)
-            else:
-                cmd_to_keys[cmd].insert(0, key)
+        key_config = objreg.get('key-config')
+        cmd_to_keys = key_config.get_reverse_bindings_for('normal')
         for (name, desc) in sorted(cmdlist):
             self.new_item(cat, name, desc, ', '.join(cmd_to_keys[name]))
 
@@ -183,7 +176,7 @@ class TabCompletionModel(base.BaseCompletionModel):
                                         window=win_id)
             for i in range(tabbed_browser.count()):
                 tab = tabbed_browser.widget(i)
-                tab.url_text_changed.connect(self.rebuild)
+                tab.url_changed.connect(self.rebuild)
                 tab.shutting_down.connect(self.delayed_rebuild)
             tabbed_browser.new_tab.connect(self.on_new_tab)
         objreg.get("app").new_window.connect(self.on_new_window)
@@ -193,10 +186,10 @@ class TabCompletionModel(base.BaseCompletionModel):
         """Add hooks to new windows."""
         window.tabbed_browser.new_tab.connect(self.on_new_tab)
 
-    @pyqtSlot(webview.WebView)
+    @pyqtSlot(browsertab.AbstractTab)
     def on_new_tab(self, tab):
         """Add hooks to new tabs."""
-        tab.url_text_changed.connect(self.rebuild)
+        tab.url_changed.connect(self.rebuild)
         tab.shutting_down.connect(self.delayed_rebuild)
         self.rebuild()
 
