@@ -34,7 +34,8 @@ from qutebrowser.mainwindow import tabbedbrowser
 from qutebrowser.mainwindow.statusbar import bar
 from qutebrowser.completion import completionwidget
 from qutebrowser.keyinput import modeman
-from qutebrowser.browser import hints, downloads, downloadview, commands
+from qutebrowser.browser import commands, downloadview, hints
+from qutebrowser.browser.webkit import downloads
 from qutebrowser.misc import crashsignal, keyhintwidget
 
 
@@ -76,7 +77,7 @@ def get_window(via_ipc, force_window=False, force_tab=False,
             win_id = window.win_id
             window_to_raise = window
         win_id = window.win_id
-        if open_target not in ('tab-silent', 'tab-bg-silent'):
+        if open_target not in ['tab-silent', 'tab-bg-silent']:
             window_to_raise = window
     if window_to_raise is not None:
         window_to_raise.setWindowState(
@@ -195,28 +196,41 @@ class MainWindow(QWidget):
     @pyqtSlot(str, str)
     def on_config_changed(self, section, option):
         """Resize the completion if related config options changed."""
-        if section == 'completion' and option in ('height', 'shrink'):
+        if section == 'completion' and option in ['height', 'shrink']:
             self.resize_completion()
         elif section == 'ui' and option == 'statusbar-padding':
             self.resize_completion()
         elif section == 'ui' and option == 'downloads-position':
             self._add_widgets()
+        elif section == 'ui' and option == 'status-position':
+            self._add_widgets()
+            self.resize_completion()
 
     def _add_widgets(self):
         """Add or readd all widgets to the VBox."""
         self._vbox.removeWidget(self.tabbed_browser)
         self._vbox.removeWidget(self._downloadview)
         self._vbox.removeWidget(self.status)
-        position = config.get('ui', 'downloads-position')
-        if position == 'top':
-            self._vbox.addWidget(self._downloadview)
-            self._vbox.addWidget(self.tabbed_browser)
-        elif position == 'bottom':
-            self._vbox.addWidget(self.tabbed_browser)
-            self._vbox.addWidget(self._downloadview)
+        downloads_position = config.get('ui', 'downloads-position')
+        status_position = config.get('ui', 'status-position')
+        widgets = [self.tabbed_browser]
+
+        if downloads_position == 'top':
+            widgets.insert(0, self._downloadview)
+        elif downloads_position == 'bottom':
+            widgets.append(self._downloadview)
         else:
-            raise ValueError("Invalid position {}!".format(position))
-        self._vbox.addWidget(self.status)
+            raise ValueError("Invalid position {}!".format(downloads_position))
+
+        if status_position == 'top':
+            widgets.insert(0, self.status)
+        elif status_position == 'bottom':
+            widgets.append(self.status)
+        else:
+            raise ValueError("Invalid position {}!".format(status_position))
+
+        for widget in widgets:
+            self._vbox.addWidget(widget)
 
     def _load_state_geometry(self):
         """Load the geometry from the state file."""
@@ -331,12 +345,8 @@ class MainWindow(QWidget):
 
         tabs.tab_index_changed.connect(status.tabindex.on_tab_index_changed)
 
-        tabs.current_tab_changed.connect(status.txt.on_tab_changed)
-        tabs.cur_statusbar_message.connect(status.txt.on_statusbar_message)
-        tabs.cur_load_started.connect(status.txt.on_load_started)
-
         tabs.current_tab_changed.connect(status.url.on_tab_changed)
-        tabs.cur_url_text_changed.connect(status.url.set_url)
+        tabs.cur_url_changed.connect(status.url.set_url)
         tabs.cur_link_hovered.connect(status.url.set_hover_url)
         tabs.cur_load_status_changed.connect(status.url.on_load_status_changed)
 
@@ -369,12 +379,19 @@ class MainWindow(QWidget):
                 height = contents_height
         else:
             contents_height = -1
-        # hpoint now would be the bottom-left edge of the widget if it was on
-        # the top of the main window.
-        topleft_y = self.height() - self.status.height() - height
-        topleft_y = qtutils.check_overflow(topleft_y, 'int', fatal=False)
-        topleft = QPoint(0, topleft_y)
-        bottomright = self.status.geometry().topRight()
+        status_position = config.get('ui', 'status-position')
+        if status_position == 'bottom':
+            top = self.height() - self.status.height() - height
+            top = qtutils.check_overflow(top, 'int', fatal=False)
+            topleft = QPoint(0, top)
+            bottomright = self.status.geometry().topRight()
+        elif status_position == 'top':
+            topleft = self.status.geometry().bottomLeft()
+            bottom = self.status.height() + height
+            bottom = qtutils.check_overflow(bottom, 'int', fatal=False)
+            bottomright = QPoint(self.width(), bottom)
+        else:
+            raise ValueError("Invalid position {}!".format(status_position))
         rect = QRect(topleft, bottomright)
         log.misc.debug('completion rect: {}'.format(rect))
         if rect.isValid():
