@@ -329,12 +329,12 @@ class StatusBar(QWidget):
             log.statusbar.debug("Setting command_active to {}".format(val))
             self._command_active = val
         elif mode == usertypes.KeyMode.caret:
-            webview = objreg.get('tabbed-browser', scope='window',
-                                 window=self._win_id).currentWidget()
+            tab = objreg.get('tabbed-browser', scope='window',
+                             window=self._win_id).currentWidget()
             log.statusbar.debug("Setting caret_mode - val {}, selection "
-                                "{}".format(val, webview.selection_enabled))
+                                "{}".format(val, tab.caret.selection_enabled))
             if val:
-                if webview.selection_enabled:
+                if tab.caret.selection_enabled:
                     self._set_mode_text("{} selection".format(mode.name))
                     self._caret_mode = CaretMode.selection
                 else:
@@ -519,9 +519,9 @@ class StatusBar(QWidget):
                                 window=self._win_id)
         if keyparsers[mode].passthrough:
             self._set_mode_text(mode.name)
-        if mode in (usertypes.KeyMode.insert,
+        if mode in [usertypes.KeyMode.insert,
                     usertypes.KeyMode.command,
-                    usertypes.KeyMode.caret):
+                    usertypes.KeyMode.caret]:
             self.set_mode_active(mode, True)
 
     @pyqtSlot(usertypes.KeyMode, usertypes.KeyMode)
@@ -534,9 +534,9 @@ class StatusBar(QWidget):
                 self._set_mode_text(new_mode.name)
             else:
                 self.txt.set_text(self.txt.Text.normal, '')
-        if old_mode in (usertypes.KeyMode.insert,
+        if old_mode in [usertypes.KeyMode.insert,
                         usertypes.KeyMode.command,
-                        usertypes.KeyMode.caret):
+                        usertypes.KeyMode.caret]:
             self.set_mode_active(old_mode, False)
 
     @config.change_filter('ui', 'message-timeout')
