@@ -153,6 +153,8 @@ def _get_tab_registry(win_id, tab_id):
         win_id = window.win_id
     elif win_id is not None:
         window = window_registry[win_id]
+    else:
+        raise TypeError("window is None with scope tab!")
 
     if tab_id == 'current':
         tabbed_browser = get('tabbed-browser', scope='window', window=win_id)
@@ -192,7 +194,7 @@ def _get_window_registry(window):
 
 def _get_registry(scope, window=None, tab=None):
     """Get the correct registry for a given scope."""
-    if window is not None and scope not in ('window', 'tab'):
+    if window is not None and scope not in ['window', 'tab']:
         raise TypeError("window is set with scope {}".format(scope))
     if tab is not None and scope != 'tab':
         raise TypeError("tab is set with scope {}".format(scope))
